@@ -310,6 +310,7 @@ var NAVTREE =
       [ "Interleaving StarPU and non-StarPU code", "FrequentlyAskedQuestions.html#PauseResume", null ],
       [ "When running with CUDA or OpenCL devices, I am seeing less CPU cores", "FrequentlyAskedQuestions.html#GPUEatingCores", null ],
       [ "StarPU does not see my CUDA device", "FrequentlyAskedQuestions.html#CUDADrivers", null ],
+      [ "StarPU does not see my HIP device", "FrequentlyAskedQuestions.html#HIPDrivers", null ],
       [ "StarPU does not see my OpenCL device", "FrequentlyAskedQuestions.html#OpenCLDrivers", null ],
       [ "There seems to be errors when copying to and from CUDA devices", "FrequentlyAskedQuestions.html#CUDACopyError", null ],
       [ "I keep getting a \"Incorrect performance model file\" error", "FrequentlyAskedQuestions.html#IncorrectPerformanceModelFile", null ]
@@ -626,21 +627,21 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "AdvancedDataManagement.html",
-"NativeFortranSupport.html#NFIdioms",
-"functions_m.html",
-"group__API__Codelet__And__Tasks.html#ga842f80f41741306e78963d5b1cec4b7f",
-"group__API__Data__Interfaces.html#ga3ef8a3c5b91f3d3b048a4e5f51a4c4c0",
-"group__API__Data__Management.html#gaf971c53b3fa3d3746a8ae1f5291c7c4f",
-"group__API__Initialization__and__Termination.html#affd5b335a988c417ecb679d5ecf7c489",
-"group__API__MPI__Support.html#gaaf806ce3131edd757470c7401bd41bd7",
-"group__API__OpenMP__Runtime__Support.html#ga1b951f0922d794e6deb2579c81bcf41b",
-"group__API__Perf__Steering.html#ga9715d7c1d761e641fce5c4ec72507d2b",
-"group__API__SC__Hypervisor.html#gaafac498199c6441e2d45c9b4eac8dfe4",
-"group__API__Task__Lists.html#ga37f7421eb2dcf9d808220db8454f0fac",
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html",
-"interfacefstarpu__mod_1_1fstarpu__free__noflag.html",
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html",
-"starpu__cusolver_8h.html#a78866b909f7e937a43d96beb983c2434"
+"NativeFortranSupport.html#NFExamples",
+"functions_l.html",
+"group__API__Codelet__And__Tasks.html#ga829d31913f4b0890192d4924bd264f88",
+"group__API__Data__Interfaces.html#ga3a3cf303a3e3be144aab7abdf587c900",
+"group__API__Data__Management.html#gaef7203edaf1725977dffac23296ede4e",
+"group__API__Initialization__and__Termination.html#aee75e823857e667c95edf346669b34ed",
+"group__API__MPI__Support.html#gaa734bb0c57e4a48a7fe6e41f2e563e68",
+"group__API__OpenMP__Runtime__Support.html#ga1080ae6a620b2c40c71311df32ab44d4",
+"group__API__Perf__Steering.html#ga7f33a85658e9f82d10cb439658ea98cf",
+"group__API__SC__Hypervisor.html#ga96ec8fb00b7c1a93b7dd9e44deabbe77",
+"group__API__Task__Lists.html#ad80731caf9d45900687caa7d5cc17cae",
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html",
+"interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html",
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html",
+"starpu__cublas_8h_source.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
