@@ -1,19 +1,25 @@
 var NAVTREEINDEX14 =
 {
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[59,0,0,256],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[59,0,0,253],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[58,0,0,253],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[59,0,0,254],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[58,0,0,254],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[59,0,0,255],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[58,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[58,0,0,256],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[59,0,0,256],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[58,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[59,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[58,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[59,0,0,258],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[59,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[58,0,0,259],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[59,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[58,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[59,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[58,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[59,0,0,261],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[58,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[59,0,0,262],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[58,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[58,0,0,263],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[59,0,0,263],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[58,0,0,264],
@@ -26,8 +32,8 @@ var NAVTREEINDEX14 =
 "interfacefstarpu__mod_1_1fstarpu__timing__now.html":[59,0,0,267],
 "interfacefstarpu__mod_1_1fstarpu__topology__print.html":[59,0,0,268],
 "interfacefstarpu__mod_1_1fstarpu__topology__print.html":[58,0,0,268],
-"interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[58,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[59,0,0,269],
+"interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[58,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[59,0,0,270],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[58,0,0,270],
 "interfacefstarpu__mod_1_1fstarpu__usleep.html":[59,0,0,271],
@@ -36,8 +42,8 @@ var NAVTREEINDEX14 =
 "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[58,0,0,272],
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[59,0,0,273],
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[58,0,0,273],
-"interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[58,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[59,0,0,274],
+"interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[58,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[59,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[58,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[59,0,0,276],
@@ -52,22 +58,22 @@ var NAVTREEINDEX14 =
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[58,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[59,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[58,0,0,281],
-"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[58,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[59,0,0,282],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[58,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[59,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[58,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[59,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[58,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[59,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[58,0,0,285],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[58,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[59,0,0,286],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[58,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[58,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[59,0,0,287],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[58,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[59,0,0,288],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[58,0,0,289],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[58,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[59,0,0,289],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[58,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[59,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[58,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[59,0,0,291],
@@ -76,16 +82,16 @@ var NAVTREEINDEX14 =
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[58,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[58,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[59,0,0,293],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[58,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[59,0,0,294],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[58,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[58,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[59,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[58,0,0,295],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[58,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[59,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[58,0,0,297],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[59,0,0,297],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[58,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[59,0,0,298],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[58,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[58,0,0,299],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[59,0,0,299],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[59,0,0,300],
@@ -241,13 +247,7 @@ var NAVTREEINDEX14 =
 "starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[60,0,5,28],
 "starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[60,0,5,4],
 "starpu__config_8h_source.html":[60,0,5],
-"starpu__cublas_8h.html":[60,0,0,5],
-"starpu__cublas_8h_source.html":[60,0,0,5],
-"starpu__cublas__v2_8h.html":[60,0,0,6],
-"starpu__cublas__v2_8h_source.html":[60,0,0,6],
-"starpu__cuda_8h.html":[60,0,0,7],
-"starpu__cuda_8h_source.html":[60,0,0,7],
-"starpu__cusolver_8h.html":[60,0,0,8],
-"starpu__cusolver_8h.html#a370a7a73030f807605a9b5e418e29852":[60,0,0,8,3],
-"starpu__cusolver_8h.html#a661622267516b78a8c71c60fa8a27c4a":[60,0,0,8,6]
+"starpu__cublasLt_8h.html":[60,0,0,7],
+"starpu__cublasLt_8h_source.html":[60,0,0,7],
+"starpu__cublas_8h.html":[60,0,0,5]
 };
