@@ -1,5 +1,10 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Perf__Steering.html#ga7f33a85658e9f82d10cb439658ea98cf":[57,36,26],
+"group__API__Perf__Steering.html#ga8091cf0aff44776750c353dc78117740":[57,36,5],
+"group__API__Perf__Steering.html#ga818f8dfca1507c1f26c6b716614ced1f":[57,36,2],
+"group__API__Perf__Steering.html#ga8ccc830962c507c32a68b19368015967":[57,36,17],
+"group__API__Perf__Steering.html#ga96203abd0ba972e7fda0e60ec6fbc5bb":[57,36,21],
 "group__API__Perf__Steering.html#ga9715d7c1d761e641fce5c4ec72507d2b":[57,36,37],
 "group__API__Perf__Steering.html#gaa17ede3e783e660a49eca0b93e453d55":[57,36,12],
 "group__API__Perf__Steering.html#gaa3355e070b7f2275deb8616bc3a8bb9b":[57,36,31],
@@ -244,10 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__SC__Hypervisor.html#ga838703a5d26ea31f7415155ecbf1e490":[57,46,48],
 "group__API__SC__Hypervisor.html#ga84e68fc3ee959e12c6b5d49b4db7a441":[57,46,36],
 "group__API__SC__Hypervisor.html#ga894cc12da13c7e07534b2f31f8aef02c":[57,46,42],
-"group__API__SC__Hypervisor.html#ga94eea335704bbfa52bc025ad4d49eb14":[57,46,9],
-"group__API__SC__Hypervisor.html#ga96ec8fb00b7c1a93b7dd9e44deabbe77":[57,46,40],
-"group__API__SC__Hypervisor.html#ga9734466cc2ae6b8fcd280a602ac1cf40":[57,46,25],
-"group__API__SC__Hypervisor.html#ga9968686b96e842b384e2fd2495c8c7ab":[57,46,27],
-"group__API__SC__Hypervisor.html#gaa2299b4916c0e8b3ffe5db762d37d092":[57,46,52],
-"group__API__SC__Hypervisor.html#gaa768d65847bee6f26861217af9437ae2":[57,46,51]
+"group__API__SC__Hypervisor.html#ga94eea335704bbfa52bc025ad4d49eb14":[57,46,9]
 };
