@@ -1,5 +1,9 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Initialization__and__Termination.html#a2275c89ee0aded13cc8836a0c5ef0188":[5,4,0,15],
+"group__API__Initialization__and__Termination.html#a27718585874f9012e9955ba308e2cd8f":[5,4,0,16],
+"group__API__Initialization__and__Termination.html#a290f151da116c90c48a1885dbba9c072":[5,4,0,32],
+"group__API__Initialization__and__Termination.html#a29b3ff0d1afa9e24a7edbb0765cea487":[5,4,0,31],
 "group__API__Initialization__and__Termination.html#a2f4b44f119a585f08418771ce62321a1":[5,4,0,43],
 "group__API__Initialization__and__Termination.html#a304d0919a6a77fe0239291a4fb40d9dc":[5,4,0,47],
 "group__API__Initialization__and__Termination.html#a30cab554913e27a02512badaf204a266":[5,4,0,20],
@@ -245,9 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga417db8086f6f19b750e7829ba725c3d3":[5,27,62],
 "group__API__MPI__Support.html#ga42225d9bf5ed973056f29f9b86907c8d":[5,27,10],
 "group__API__MPI__Support.html#ga4599b229ca7699c320468ae8e2e63f93":[5,27,78],
-"group__API__MPI__Support.html#ga4796df4827fd94bff177b4232e380d8a":[5,27,41],
-"group__API__MPI__Support.html#ga4799c69cb64cee04cfff4917f7cdf151":[5,27,17],
-"group__API__MPI__Support.html#ga48bd2a2569bd00cf4d1500e642015685":[5,27,89],
-"group__API__MPI__Support.html#ga4cd283c401aa59ae226bd1c5da1b295f":[5,27,108],
-"group__API__MPI__Support.html#ga5281ad23b39e64ca254347e89cbb54e2":[5,27,13]
+"group__API__MPI__Support.html#ga4796df4827fd94bff177b4232e380d8a":[5,27,41]
 };
