@@ -1,5 +1,9 @@
 var NAVTREEINDEX8 =
 {
+"group__API__SC__Hypervisor.html#a79c6a87b792c849cc6c388dbf17d2d49":[5,47,1,4],
+"group__API__SC__Hypervisor.html#a829c79920efa453ee18491e8a85c1ff6":[5,47,3,3],
+"group__API__SC__Hypervisor.html#a838a86b485c9091ab11ea78bfbd12edd":[5,47,2,2],
+"group__API__SC__Hypervisor.html#a9a8cebea8354bedd492764a53037f000":[5,47,2,7],
 "group__API__SC__Hypervisor.html#a9aba37893ddb344de680aa901f686f2d":[5,47,3,1],
 "group__API__SC__Hypervisor.html#ab44752ac4a1d34c397d8fe8b10e8611b":[5,47,2,6],
 "group__API__SC__Hypervisor.html#ac676ac4892a469ad4674b560c2b92514":[5,47,2,10],
@@ -245,9 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#structstarpu__sched__policy":[5,24,0],
 "group__API__Sink.html":[5,43],
 "group__API__Standard__Memory__Library.html":[5,44],
-"group__API__Standard__Memory__Library.html#ga13b23ecc431501f8aebcb7b498acd92b":[5,44,19],
-"group__API__Standard__Memory__Library.html#ga1456598a362e4ee275247bd1a1d4327b":[5,44,22],
-"group__API__Standard__Memory__Library.html#ga18cb9a696ddb392c6874939c8cffd495":[5,44,20],
-"group__API__Standard__Memory__Library.html#ga2abe959e39acfb75c7c0652706dfe84c":[5,44,0],
-"group__API__Standard__Memory__Library.html#ga3506e4b5ab7a605e25968883ded27d64":[5,44,17]
+"group__API__Standard__Memory__Library.html#ga13b23ecc431501f8aebcb7b498acd92b":[5,44,19]
 };
