@@ -1,40 +1,45 @@
 var NAVTREEINDEX11 =
 {
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[11,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[12,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[11,0,0,84],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[12,0,0,84],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[12,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[11,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[12,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[11,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[12,0,0,87],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[11,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[11,0,0,88],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[12,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[12,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[11,0,0,88],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[11,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[12,0,0,89],
 "interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[12,0,0,90],
 "interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[11,0,0,90],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[12,0,0,91],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[11,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[12,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition.html":[11,0,0,92],
+"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[12,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[12,0,0,93],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[11,0,0,93],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[12,0,0,94],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[11,0,0,94],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[12,0,0,95],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[11,0,0,95],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[12,0,0,96],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[11,0,0,96],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[12,0,0,97],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[12,0,0,96],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[11,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[12,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[12,0,0,97],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[11,0,0,98],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[12,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[12,0,0,98],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[11,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[12,0,0,99],
 "interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[11,0,0,100],
 "interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[12,0,0,100],
 "interfacefstarpu__mod_1_1fstarpu__data__release.html":[11,0,0,101],
 "interfacefstarpu__mod_1_1fstarpu__data__release.html":[12,0,0,101],
-"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[11,0,0,102],
 "interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[12,0,0,102],
+"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[11,0,0,102],
 "interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[12,0,0,103],
 "interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[11,0,0,103],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[11,0,0,104],
@@ -73,10 +78,10 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[12,0,0,120],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[11,0,0,121],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[12,0,0,121],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[11,0,0,122],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[12,0,0,122],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[11,0,0,123],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[11,0,0,122],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[12,0,0,123],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[11,0,0,123],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[12,0,0,124],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[11,0,0,124],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[11,0,0,125],
@@ -225,8 +230,8 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[11,0,0,196],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[11,0,0,197],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[12,0,0,197],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[11,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[12,0,0,198],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[11,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[11,0,0,199],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[12,0,0,199],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[11,0,0,200],
@@ -235,19 +240,14 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[12,0,0,201],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[11,0,0,202],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[12,0,0,202],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[12,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[11,0,0,203],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[11,0,0,204],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[12,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[12,0,0,204],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[11,0,0,205],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[11,0,0,204],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[12,0,0,205],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[11,0,0,206],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[11,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[12,0,0,206],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[11,0,0,206],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[11,0,0,207],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[12,0,0,207],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[11,0,0,208],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[12,0,0,208],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[11,0,0,209],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[12,0,0,209],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[12,0,0,210]
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[12,0,0,207]
 };
