@@ -1,56 +1,61 @@
 var NAVTREEINDEX12 =
 {
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[12,0,0,208],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[11,0,0,208],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[12,0,0,209],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[11,0,0,209],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[12,0,0,210],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[11,0,0,210],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[12,0,0,211],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[11,0,0,211],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[12,0,0,212],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[11,0,0,212],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[11,0,0,213],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[12,0,0,213],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[11,0,0,214],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[11,0,0,213],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[12,0,0,214],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[11,0,0,215],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[11,0,0,214],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[12,0,0,215],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[11,0,0,215],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[11,0,0,216],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[12,0,0,216],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[11,0,0,217],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[12,0,0,217],
-"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[12,0,0,218],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[11,0,0,218],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[12,0,0,219],
+"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[12,0,0,218],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[11,0,0,219],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[12,0,0,219],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[11,0,0,220],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[12,0,0,220],
-"interfacefstarpu__mod_1_1fstarpu__shutdown.html":[12,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[11,0,0,221],
+"interfacefstarpu__mod_1_1fstarpu__shutdown.html":[12,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__sleep.html":[11,0,0,222],
 "interfacefstarpu__mod_1_1fstarpu__sleep.html":[12,0,0,222],
-"interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[11,0,0,223],
 "interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[12,0,0,223],
+"interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[11,0,0,223],
 "interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[11,0,0,224],
 "interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[12,0,0,224],
-"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[12,0,0,225],
 "interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[11,0,0,225],
+"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[12,0,0,225],
 "interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[12,0,0,226],
 "interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[11,0,0,226],
-"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[11,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[12,0,0,227],
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[11,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[11,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[12,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[11,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[12,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[11,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[12,0,0,230],
-"interfacefstarpu__mod_1_1fstarpu__task__create.html":[12,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[11,0,0,231],
-"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[11,0,0,232],
+"interfacefstarpu__mod_1_1fstarpu__task__create.html":[12,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[12,0,0,232],
+"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[11,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[11,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[12,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[12,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[11,0,0,234],
-"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[12,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[11,0,0,235],
+"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[12,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[12,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[11,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[12,0,0,237],
@@ -59,26 +64,26 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[11,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[12,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[11,0,0,239],
-"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[11,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[12,0,0,240],
-"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[12,0,0,241],
+"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[11,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[11,0,0,241],
+"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[12,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[11,0,0,242],
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[12,0,0,242],
-"interfacefstarpu__mod_1_1fstarpu__task__insert.html":[12,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[11,0,0,243],
-"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[11,0,0,244],
+"interfacefstarpu__mod_1_1fstarpu__task__insert.html":[12,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[12,0,0,244],
-"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[12,0,0,245],
+"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[11,0,0,244],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[11,0,0,245],
-"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[11,0,0,246],
+"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[12,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[12,0,0,246],
+"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[11,0,0,246],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[11,0,0,247],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[12,0,0,247],
 "interfacefstarpu__mod_1_1fstarpu__task__submit.html":[11,0,0,248],
 "interfacefstarpu__mod_1_1fstarpu__task__submit.html":[12,0,0,248],
-"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[12,0,0,249],
 "interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[11,0,0,249],
+"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[12,0,0,249],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[12,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[11,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[12,0,0,251],
@@ -95,8 +100,8 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[11,0,0,256],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[12,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[11,0,0,257],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[11,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[12,0,0,258],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[11,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[11,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[12,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[11,0,0,260],
@@ -107,16 +112,16 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[12,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[11,0,0,263],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[12,0,0,263],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[12,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[11,0,0,264],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[11,0,0,265],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[12,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[12,0,0,265],
-"interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[12,0,0,266],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[11,0,0,265],
 "interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[11,0,0,266],
+"interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[12,0,0,266],
 "interfacefstarpu__mod_1_1fstarpu__timing__now.html":[12,0,0,267],
 "interfacefstarpu__mod_1_1fstarpu__timing__now.html":[11,0,0,267],
-"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[11,0,0,268],
 "interfacefstarpu__mod_1_1fstarpu__topology__print.html":[12,0,0,268],
+"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[11,0,0,268],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[11,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[12,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[11,0,0,270],
@@ -129,14 +134,14 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[12,0,0,273],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[11,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[12,0,0,274],
-"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[12,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[11,0,0,275],
+"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[12,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[12,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[11,0,0,276],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[11,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[12,0,0,277],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[12,0,0,278],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[11,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[11,0,0,278],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[12,0,0,278],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[12,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[11,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[12,0,0,280],
@@ -145,40 +150,40 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[11,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[12,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[11,0,0,282],
-"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[11,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[12,0,0,283],
+"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[11,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[11,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[12,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[11,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[12,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[11,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[12,0,0,286],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[11,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[12,0,0,287],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[11,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[11,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[12,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[11,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[12,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[11,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[12,0,0,290],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[12,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[11,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[12,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[12,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[11,0,0,292],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[12,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[11,0,0,293],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[12,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[12,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[11,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[12,0,0,295],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[11,0,0,295],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[11,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[12,0,0,296],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[11,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[12,0,0,297],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[11,0,0,297],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[12,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[11,0,0,298],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[11,0,0,299],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[12,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[12,0,0,299],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[11,0,0,299],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[12,0,0,300],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[11,0,0,300],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[12,0,1,0],
@@ -244,10 +249,5 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__task__build.html":[12,0,1,60],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__task__insert.html":[12,0,1,61],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__task__post__build.html":[12,0,1,62],
-"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__test.html":[12,0,1,63],
-"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__wait.html":[12,0,1,64],
-"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__wait__for__all.html":[12,0,1,65],
-"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__world__comm.html":[12,0,1,66],
-"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__world__rank.html":[12,0,1,67],
-"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__world__size.html":[12,0,1,68]
+"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__test.html":[12,0,1,63]
 };
