@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Worker.html#ga4e3f3eec12a1cd4285a3f8938a9c240d":[10,37,4],
+"group__API__Parallel__Worker.html#ga5d4d41c174aac7219a8ec9dd4136ace6":[10,37,12],
+"group__API__Parallel__Worker.html#ga5dc009221d5edb074372761574238dac":[10,37,6],
+"group__API__Parallel__Worker.html#ga63c001ace567446514f1616e34af1bf6":[10,37,29],
 "group__API__Parallel__Worker.html#ga6418a1fed34b32217d66860cbf8fc200":[10,37,24],
 "group__API__Parallel__Worker.html#ga6cd34b24aaea1b26df96b7aff9238759":[10,37,22],
 "group__API__Parallel__Worker.html#ga6dc4b6d66ef90b7927559c9e2728a84b":[10,37,21],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#aae7bd9f557dffe9883629df980eee606":[10,40,0,9],
 "group__API__Profiling.html#ab8de457be74df606d29c3efa1169998a":[10,40,0,7],
 "group__API__Profiling.html#acc882d8569e28d51fd5e820962fed773":[10,40,1,5],
-"group__API__Profiling.html#ada5d73c7df113b540914f84e95963fb9":[10,40,1,6],
-"group__API__Profiling.html#ade189cd6175d789db1eb6bfad19b3e35":[10,40,0,8],
-"group__API__Profiling.html#aec88f33a8b4777727d80296c16d85f24":[10,40,0,14],
-"group__API__Profiling.html#aed6a8be9b919f03e093912bfc44c5559":[10,40,1,0],
-"group__API__Profiling.html#ga1e388939370daaf139c73678e413f00a":[10,40,3]
+"group__API__Profiling.html#ada5d73c7df113b540914f84e95963fb9":[10,40,1,6]
 };
