@@ -1,21 +1,26 @@
 var NAVTREEINDEX13 =
 {
+"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[27,0,0,281],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[26,0,0,282],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[27,0,0,282],
+"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[27,0,0,283],
+"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[26,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[27,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[26,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[27,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[26,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[27,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[26,0,0,286],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[27,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[26,0,0,287],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[27,0,0,288],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[27,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[26,0,0,288],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[27,0,0,289],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[27,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[26,0,0,289],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[27,0,0,290],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[27,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[26,0,0,290],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[27,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[27,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[26,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[27,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[26,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[27,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[27,0,0,293],
@@ -30,10 +35,10 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[26,0,0,297],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[27,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[26,0,0,298],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[26,0,0,299],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[27,0,0,299],
-"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[27,0,0,300],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[26,0,0,299],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[26,0,0,300],
+"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[27,0,0,300],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[27,0,1,0],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush.html":[27,0,1,1],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush__all__data.html":[27,0,1,2],
@@ -185,49 +190,51 @@ var NAVTREEINDEX13 =
 "starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[28,0,0,0,28],
 "starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[28,0,0,0,4],
 "starpu__config_8h_source.html":[28,0,0,0],
+"starpu__cublasLt_8h.html":[28,0,1,7],
+"starpu__cublasLt_8h_source.html":[28,0,1,7],
 "starpu__cublas_8h.html":[28,0,1,5],
 "starpu__cublas_8h_source.html":[28,0,1,5],
 "starpu__cublas__v2_8h.html":[28,0,1,6],
 "starpu__cublas__v2_8h_source.html":[28,0,1,6],
-"starpu__cuda_8h.html":[28,0,1,7],
-"starpu__cuda_8h_source.html":[28,0,1,7],
-"starpu__cusolver_8h.html":[28,0,1,8],
-"starpu__cusolver_8h.html#a370a7a73030f807605a9b5e418e29852":[28,0,1,8,3],
-"starpu__cusolver_8h.html#a661622267516b78a8c71c60fa8a27c4a":[28,0,1,8,6],
-"starpu__cusolver_8h.html#a78866b909f7e937a43d96beb983c2434":[28,0,1,8,5],
-"starpu__cusolver_8h.html#a802c617673805d37d62a3213261d121e":[28,0,1,8,4],
-"starpu__cusolver_8h.html#aa27808f9256c0b90c2c231b598b16220":[28,0,1,8,0],
-"starpu__cusolver_8h.html#adc9d0c6e8728152c6ede31a828c353a6":[28,0,1,8,2],
-"starpu__cusolver_8h_source.html":[28,0,1,8],
-"starpu__cusparse_8h.html":[28,0,1,9],
-"starpu__cusparse_8h_source.html":[28,0,1,9],
-"starpu__data_8h.html":[28,0,1,10],
-"starpu__data_8h_source.html":[28,0,1,10],
-"starpu__data__filters_8h.html":[28,0,1,11],
-"starpu__data__filters_8h_source.html":[28,0,1,11],
-"starpu__data__interfaces_8h.html":[28,0,1,12],
-"starpu__data__interfaces_8h_source.html":[28,0,1,12],
-"starpu__deprecated__api_8h.html":[28,0,1,13],
-"starpu__deprecated__api_8h_source.html":[28,0,1,13],
-"starpu__disk_8h.html":[28,0,1,14],
-"starpu__disk_8h_source.html":[28,0,1,14],
-"starpu__driver_8h.html":[28,0,1,15],
-"starpu__driver_8h_source.html":[28,0,1,15],
-"starpu__expert_8h.html":[28,0,1,16],
-"starpu__expert_8h_source.html":[28,0,1,16],
-"starpu__fxt_8h.html":[28,0,1,17],
-"starpu__fxt_8h_source.html":[28,0,1,17],
-"starpu__hash_8h.html":[28,0,1,18],
-"starpu__hash_8h_source.html":[28,0,1,18],
-"starpu__helper_8h.html":[28,0,1,19],
-"starpu__helper_8h_source.html":[28,0,1,19],
+"starpu__cuda_8h.html":[28,0,1,8],
+"starpu__cuda_8h_source.html":[28,0,1,8],
+"starpu__cusolver_8h.html":[28,0,1,9],
+"starpu__cusolver_8h.html#a370a7a73030f807605a9b5e418e29852":[28,0,1,9,3],
+"starpu__cusolver_8h.html#a661622267516b78a8c71c60fa8a27c4a":[28,0,1,9,6],
+"starpu__cusolver_8h.html#a78866b909f7e937a43d96beb983c2434":[28,0,1,9,5],
+"starpu__cusolver_8h.html#a802c617673805d37d62a3213261d121e":[28,0,1,9,4],
+"starpu__cusolver_8h.html#aa27808f9256c0b90c2c231b598b16220":[28,0,1,9,0],
+"starpu__cusolver_8h.html#adc9d0c6e8728152c6ede31a828c353a6":[28,0,1,9,2],
+"starpu__cusolver_8h_source.html":[28,0,1,9],
+"starpu__cusparse_8h.html":[28,0,1,10],
+"starpu__cusparse_8h_source.html":[28,0,1,10],
+"starpu__data_8h.html":[28,0,1,11],
+"starpu__data_8h_source.html":[28,0,1,11],
+"starpu__data__filters_8h.html":[28,0,1,12],
+"starpu__data__filters_8h_source.html":[28,0,1,12],
+"starpu__data__interfaces_8h.html":[28,0,1,13],
+"starpu__data__interfaces_8h_source.html":[28,0,1,13],
+"starpu__deprecated__api_8h.html":[28,0,1,14],
+"starpu__deprecated__api_8h_source.html":[28,0,1,14],
+"starpu__disk_8h.html":[28,0,1,15],
+"starpu__disk_8h_source.html":[28,0,1,15],
+"starpu__driver_8h.html":[28,0,1,16],
+"starpu__driver_8h_source.html":[28,0,1,16],
+"starpu__expert_8h.html":[28,0,1,17],
+"starpu__expert_8h_source.html":[28,0,1,17],
+"starpu__fxt_8h.html":[28,0,1,18],
+"starpu__fxt_8h_source.html":[28,0,1,18],
+"starpu__hash_8h.html":[28,0,1,19],
+"starpu__hash_8h_source.html":[28,0,1,19],
+"starpu__helper_8h.html":[28,0,1,20],
+"starpu__helper_8h_source.html":[28,0,1,20],
 "starpu__heteroprio_8h.html":[28,0,1,0,0],
 "starpu__heteroprio_8h_source.html":[28,0,1,0,0],
-"starpu__hip_8h.html":[28,0,1,20],
-"starpu__hip_8h_source.html":[28,0,1,20],
-"starpu__max__fpga_8h.html":[28,0,1,21],
-"starpu__max__fpga_8h_source.html":[28,0,1,21],
-"starpu__mod_8f90.html":[28,0,1,22],
+"starpu__hip_8h.html":[28,0,1,21],
+"starpu__hip_8h_source.html":[28,0,1,21],
+"starpu__max__fpga_8h.html":[28,0,1,22],
+"starpu__max__fpga_8h_source.html":[28,0,1,22],
+"starpu__mod_8f90.html":[28,0,1,23],
 "starpu__mpi_8h.html":[28,0,2,0,0],
 "starpu__mpi_8h_source.html":[28,0,2,0,0],
 "starpu__mpi__ft_8h.html":[28,0,2,0,1],
@@ -235,19 +242,12 @@ var NAVTREEINDEX13 =
 "starpu__mpi__lb_8h.html":[28,0,2,0,2],
 "starpu__mpi__lb_8h.html#a1692d18d1d2d0df9eae6c148d54167f1":[28,0,2,0,2,1],
 "starpu__mpi__lb_8h_source.html":[28,0,2,0,2],
-"starpu__opencl_8h.html":[28,0,1,23],
-"starpu__opencl_8h_source.html":[28,0,1,23],
-"starpu__openmp_8h.html":[28,0,1,24],
-"starpu__openmp_8h_source.html":[28,0,1,24],
-"starpu__parallel__worker_8h.html":[28,0,1,25],
-"starpu__parallel__worker_8h_source.html":[28,0,1,25],
-"starpu__perf__monitoring_8h.html":[28,0,1,26],
-"starpu__perf__monitoring_8h_source.html":[28,0,1,26],
-"starpu__perf__steering_8h.html":[28,0,1,27],
-"starpu__perf__steering_8h_source.html":[28,0,1,27],
-"starpu__perfmodel_8h.html":[28,0,1,28],
-"starpu__perfmodel_8h_source.html":[28,0,1,28],
-"starpu__profiling_8h.html":[28,0,1,29],
-"starpu__profiling_8h_source.html":[28,0,1,29],
-"starpu__profiling__tool_8h.html":[28,0,1,30]
+"starpu__opencl_8h.html":[28,0,1,24],
+"starpu__opencl_8h_source.html":[28,0,1,24],
+"starpu__openmp_8h.html":[28,0,1,25],
+"starpu__openmp_8h_source.html":[28,0,1,25],
+"starpu__parallel__worker_8h.html":[28,0,1,26],
+"starpu__parallel__worker_8h_source.html":[28,0,1,26],
+"starpu__perf__monitoring_8h.html":[28,0,1,27],
+"starpu__perf__monitoring_8h_source.html":[28,0,1,27]
 };
