@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Max__FPGA__Extensions.html#ga6dfcf82c7b941a50a9bc2e478dfc4897":[25,17,1],
+"group__API__Max__FPGA__Extensions.html#ga7f7a92414ff1a98d7523bc40f36d0878":[25,17,2],
+"group__API__Max__FPGA__Extensions.html#gaab45e70c85fc1786d6d5e618fd5c3922":[25,17,3],
+"group__API__Max__FPGA__Extensions.html#structstarpu__max__load":[25,17,0],
 "group__API__Miscellaneous__Helpers.html":[25,36],
 "group__API__Miscellaneous__Helpers.html#ga090e97b588f83718c19f0ed3d07d1d70":[25,36,14],
 "group__API__Miscellaneous__Helpers.html#ga0e762c057c5206bd093534e5dd145b1c":[25,36,17],
@@ -245,9 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__OpenMP__Runtime__Support.html#ga8de196a9b2248ee34f9183a081da8be5":[25,21,49],
 "group__API__OpenMP__Runtime__Support.html#ga906913c3eb454506682a130c6bcd6337":[25,21,48],
 "group__API__OpenMP__Runtime__Support.html#ga9db57e7c1c67a02837b279145fb1883d":[25,21,16],
-"group__API__OpenMP__Runtime__Support.html#ga9f66990dcc824f3078afbba559817c8d":[25,21,13],
-"group__API__OpenMP__Runtime__Support.html#gaa15212ca3137d7aba827794b26fee9e0":[25,21,44],
-"group__API__OpenMP__Runtime__Support.html#gaa3127cc9d95397b4f066cef20f9ef99d":[25,21,17],
-"group__API__OpenMP__Runtime__Support.html#gaa4b70af0a6cf757e05e300c5eeea0a46":[25,21,8],
-"group__API__OpenMP__Runtime__Support.html#gaa5c38dfec313088ca5e527a97f40969d":[25,21,7]
+"group__API__OpenMP__Runtime__Support.html#ga9f66990dcc824f3078afbba559817c8d":[25,21,13]
 };
