@@ -192,6 +192,8 @@ var fstarpu__mod_8f90 =
     [ "fstarpu_mod::fstarpu_data_unregister", "interfacefstarpu__mod_1_1fstarpu__data__unregister.html", null ],
     [ "fstarpu_mod::fstarpu_data_unregister_no_coherency", "interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html", null ],
     [ "fstarpu_mod::fstarpu_data_unregister_submit", "interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html", null ],
+    [ "fstarpu_mod::fstarpu_data_deinitialize", "interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html", null ],
+    [ "fstarpu_mod::fstarpu_data_deinitialize_submit", "interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html", null ],
     [ "fstarpu_mod::fstarpu_data_invalidate", "interfacefstarpu__mod_1_1fstarpu__data__invalidate.html", null ],
     [ "fstarpu_mod::fstarpu_data_invalidate_submit", "interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html", null ],
     [ "fstarpu_mod::fstarpu_data_advise_as_important", "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html", null ],
