@@ -1,31 +1,37 @@
 var NAVTREEINDEX12 =
 {
+"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[7,0,0,225],
+"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[6,0,0,225],
+"interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[6,0,0,226],
+"interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[7,0,0,226],
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[7,0,0,227],
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[6,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[6,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[7,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[6,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[7,0,0,229],
-"interfacefstarpu__mod_1_1fstarpu__task__clean.html":[7,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[6,0,0,230],
+"interfacefstarpu__mod_1_1fstarpu__task__clean.html":[7,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[7,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[6,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[7,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[6,0,0,232],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[7,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[6,0,0,233],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[6,0,0,234],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[7,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[7,0,0,234],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[6,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[6,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[7,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[7,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[6,0,0,236],
-"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[7,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[6,0,0,237],
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[7,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[7,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[6,0,0,238],
-"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[7,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[6,0,0,239],
-"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[6,0,0,240],
+"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[7,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[7,0,0,240],
+"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[6,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[6,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[7,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[6,0,0,242],
@@ -36,42 +42,42 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[6,0,0,244],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[7,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[6,0,0,245],
-"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[7,0,0,246],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[6,0,0,246],
-"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[7,0,0,247],
+"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[7,0,0,246],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[6,0,0,247],
+"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[7,0,0,247],
 "interfacefstarpu__mod_1_1fstarpu__task__submit.html":[7,0,0,248],
 "interfacefstarpu__mod_1_1fstarpu__task__submit.html":[6,0,0,248],
-"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[7,0,0,249],
 "interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[6,0,0,249],
+"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[7,0,0,249],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[7,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[6,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[7,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[6,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[6,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[7,0,0,252],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[7,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[6,0,0,253],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[7,0,0,254],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[7,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[6,0,0,254],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[7,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[6,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[7,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[6,0,0,256],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[7,0,0,256],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[6,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[7,0,0,257],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[7,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[6,0,0,258],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[7,0,0,259],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[7,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[6,0,0,259],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[6,0,0,260],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[7,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[7,0,0,260],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[6,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[7,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[6,0,0,261],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[7,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[6,0,0,262],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[6,0,0,263],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[7,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[7,0,0,263],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[6,0,0,263],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[7,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[6,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[6,0,0,265],
@@ -86,28 +92,28 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[7,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[6,0,0,270],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[7,0,0,270],
-"interfacefstarpu__mod_1_1fstarpu__usleep.html":[7,0,0,271],
 "interfacefstarpu__mod_1_1fstarpu__usleep.html":[6,0,0,271],
-"interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[6,0,0,272],
+"interfacefstarpu__mod_1_1fstarpu__usleep.html":[7,0,0,271],
 "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[7,0,0,272],
-"interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[6,0,0,273],
+"interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[6,0,0,272],
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[7,0,0,273],
+"interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[6,0,0,273],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[6,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[7,0,0,274],
-"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[6,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[7,0,0,275],
+"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[6,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[6,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[7,0,0,276],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[7,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[6,0,0,277],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[7,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[6,0,0,278],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[7,0,0,278],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[6,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[7,0,0,279],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[7,0,0,280],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[6,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[6,0,0,280],
-"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[7,0,0,281],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[7,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[6,0,0,281],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[7,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[6,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[7,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[6,0,0,283],
@@ -118,34 +124,34 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[7,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[6,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[7,0,0,286],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[7,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[6,0,0,287],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[7,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[7,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[6,0,0,288],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[6,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[7,0,0,289],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[7,0,0,290],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[6,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[6,0,0,290],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[7,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[7,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[6,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[7,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[6,0,0,292],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[6,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[7,0,0,293],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[6,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[7,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[6,0,0,294],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[7,0,0,295],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[6,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[7,0,0,295],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[7,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[6,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[7,0,0,297],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[6,0,0,297],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[7,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[6,0,0,298],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[7,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[7,0,0,299],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[6,0,0,299],
-"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[6,0,0,300],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[7,0,0,300],
+"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[6,0,0,300],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[7,0,1,0],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush.html":[7,0,1,1],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush__all__data.html":[7,0,1,2],
@@ -243,11 +249,5 @@ var NAVTREEINDEX12 =
 "sc__hypervisor__config_8h.html#a963cb56195d9fa30e905a4d1ba0c4300":[8,0,3,0,1,0,1],
 "sc__hypervisor__config_8h.html#a9e0d3d7192aa552436227f5886dc0075":[8,0,3,0,1,0,0],
 "sc__hypervisor__config_8h.html#ab2ceb91193882e327559323f3669262b":[8,0,3,0,1,0,6],
-"sc__hypervisor__config_8h.html#ac56775b3eafc46d10aaf2162676b72d0":[8,0,3,0,1,0,8],
-"sc__hypervisor__config_8h.html#afdb68c657fb202f52938f5268749003d":[8,0,3,0,1,0,5],
-"sc__hypervisor__config_8h.html#structsc__hypervisor__policy__config":[8,0,3,0,1,0],
-"sc__hypervisor__config_8h_source.html":[8,0,3,0,1],
-"sc__hypervisor__lp_8h.html":[8,0,3,0,2],
-"sc__hypervisor__lp_8h_source.html":[8,0,3,0,2],
-"sc__hypervisor__monitoring_8h.html":[8,0,3,0,3]
+"sc__hypervisor__config_8h.html#ac56775b3eafc46d10aaf2162676b72d0":[8,0,3,0,1,0,8]
 };
