@@ -1,5 +1,8 @@
 var NAVTREEINDEX2 =
 {
+"group__API__Data__Interfaces.html#ae002548f6392819ff90d72f64898dca6":[5,9,1,11],
+"group__API__Data__Interfaces.html#ae039cff4622424d30f99811665f4de4f":[5,9,10,6],
+"group__API__Data__Interfaces.html#ae04050a90bd86fe5b8462b62aaa9547e":[5,9,0,16],
 "group__API__Data__Interfaces.html#ae1d888af673475dbcf85104b6c359a6e":[5,9,0,12],
 "group__API__Data__Interfaces.html#ae2a9b938ace8afeb6de759dadb7181a5":[5,9,4,0],
 "group__API__Data__Interfaces.html#ae2bd3e92fba4412cabef91740fa6d30f":[5,9,4,9],
@@ -246,8 +249,5 @@ var NAVTREEINDEX2 =
 "group__API__Data__Interfaces.html#structstarpu__data__copy__methods":[5,9,0],
 "group__API__Data__Interfaces.html#structstarpu__data__interface__ops":[5,9,1],
 "group__API__Data__Interfaces.html#structstarpu__matrix__interface":[5,9,2],
-"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[5,9,11],
-"group__API__Data__Interfaces.html#structstarpu__multiformat__interface":[5,9,12],
-"group__API__Data__Interfaces.html#structstarpu__ndim__interface":[5,9,6],
-"group__API__Data__Interfaces.html#structstarpu__tensor__interface":[5,9,5]
+"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[5,9,11]
 };
