@@ -1,5 +1,10 @@
 var NAVTREEINDEX4 =
 {
+"group__API__HIP__Extensions.html#ga895d3031a83129e4c874eadedcfb1912":[5,16,1],
+"group__API__HIP__Extensions.html#ga9d7b2131ca9ed0d19535dcf5123145e2":[5,16,6],
+"group__API__HIP__Extensions.html#gaa67b3b12e9a0cce70c593b981ba14403":[5,16,9],
+"group__API__HIP__Extensions.html#gacb4a406b018e823790805c9d915dd052":[5,16,3],
+"group__API__HIP__Extensions.html#gad40f30899d319b57afe87e9f11e873e6":[5,16,12],
 "group__API__HIP__Extensions.html#gad433b07789156fd12e47cf35373d36c8":[5,16,4],
 "group__API__HIP__Extensions.html#gadc796fee8ebed3e8f4c12fb242f4c857":[5,16,5],
 "group__API__HIP__Extensions.html#gaea7ebef965850bb064607be8103e2c92":[5,16,10],
@@ -244,10 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga04576f1478a0416cd838c01269ba31a5":[5,27,8],
 "group__API__MPI__Support.html#ga0a464b972068bac652622d6a1ed0a996":[5,27,80],
 "group__API__MPI__Support.html#ga0b56f54628340aa2a47b080f96076f01":[5,27,25],
-"group__API__MPI__Support.html#ga0ec1ce958654468b20224c9ae772f98f":[5,27,22],
-"group__API__MPI__Support.html#ga1998499da59f8849a7ee5de16b0f5bab":[5,27,48],
-"group__API__MPI__Support.html#ga1d0194c08bd343a68c833f449fb62fa8":[5,27,33],
-"group__API__MPI__Support.html#ga1def2741166f560a0fb91f012538087f":[5,27,117],
-"group__API__MPI__Support.html#ga223329eeb7c711b1b213604355981185":[5,27,7],
-"group__API__MPI__Support.html#ga234e28905c976ed1b03fcdf75812a06d":[5,27,23]
+"group__API__MPI__Support.html#ga0ec1ce958654468b20224c9ae772f98f":[5,27,22]
 };
