@@ -1,5 +1,7 @@
 var NAVTREEINDEX1 =
 {
+"group__API__Codelet__And__Tasks.html#ad4b215b1fc4ae0fc29c98cf8a26029c7":[7,6,2,23],
+"group__API__Codelet__And__Tasks.html#ad5f00ed5a0a59b72c0d90d9718376893":[7,6,0,4],
 "group__API__Codelet__And__Tasks.html#ad6dfcbb8bb86ca8ce0678b4b10bf853b":[7,6,0,28],
 "group__API__Codelet__And__Tasks.html#ad75b205c087b8248adfc91892eb5f6da":[7,6,2,67],
 "group__API__Codelet__And__Tasks.html#adac9af88fed23241fc65259712352126":[7,6,2,14],
@@ -247,7 +249,5 @@ var NAVTREEINDEX1 =
 "group__API__Data__Interfaces.html#ad9ae80b9516186ddfd6ee34b74c85674":[7,9,7,4],
 "group__API__Data__Interfaces.html#add029fa5a3dc52c964587d97aca34263":[7,9,0,24],
 "group__API__Data__Interfaces.html#ade38975067536d0e2c8ff5e9480fa6fb":[7,9,6,4],
-"group__API__Data__Interfaces.html#ade630b6788a5cc8ee587fda066f9fc6f":[7,9,0,20],
-"group__API__Data__Interfaces.html#adf548c64da75d9ba392aec9f6cbb8884":[7,9,1,7],
-"group__API__Data__Interfaces.html#ae002548f6392819ff90d72f64898dca6":[7,9,1,11]
+"group__API__Data__Interfaces.html#ade630b6788a5cc8ee587fda066f9fc6f":[7,9,0,20]
 };
