@@ -1,5 +1,7 @@
 var NAVTREEINDEX3 =
 {
+"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[7,9,11],
+"group__API__Data__Interfaces.html#structstarpu__multiformat__interface":[7,9,12],
 "group__API__Data__Interfaces.html#structstarpu__ndim__interface":[7,9,6],
 "group__API__Data__Interfaces.html#structstarpu__tensor__interface":[7,9,5],
 "group__API__Data__Interfaces.html#structstarpu__variable__interface":[7,9,8],
@@ -194,6 +196,7 @@ var NAVTREEINDEX3 =
 "group__API__Explicit__Dependencies.html":[7,11],
 "group__API__Explicit__Dependencies.html#ga19e120568fbd21fcac59b93ff324c45f":[7,11,4],
 "group__API__Explicit__Dependencies.html#ga1a93d3d46ea5ade29a3a3ea76b6eb90d":[7,11,8],
+"group__API__Explicit__Dependencies.html#ga2425f146494ef50105f99325f4120522":[7,11,18],
 "group__API__Explicit__Dependencies.html#ga2ab771900cf19e039ade46594dbc5fce":[7,11,3],
 "group__API__Explicit__Dependencies.html#ga53dc7bff09b441ee6a200cae99ca2cb8":[7,11,5],
 "group__API__Explicit__Dependencies.html#ga6d09446c8849f42edeced84c558e6a49":[7,11,17],
@@ -232,6 +235,7 @@ var NAVTREEINDEX3 =
 "group__API__FxT__Support.html#ad989ef1acebea5296285ba1543b9b8d3":[7,34,2,2],
 "group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c":[7,34,1,0],
 "group__API__FxT__Support.html#ae8b5695146698ba1d5aef8c9237b5272":[7,34,2,3],
+"group__API__FxT__Support.html#ga044878f9b946fd4c265ba6e725e2468c":[7,34,9],
 "group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1":[7,34,7],
 "group__API__FxT__Support.html#ga52a3e1a95689315f0b789a3325ec2a90":[7,34,5],
 "group__API__FxT__Support.html#ga5793bf5c8fc0bedf76d18a5fa38593df":[7,34,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX3 =
 "group__API__HIP__Extensions.html#ga1a691d2cef9367d76ba912bef672455f":[7,16,11],
 "group__API__HIP__Extensions.html#ga2b471b1bf5b6f10b347818f708c0a62f":[7,16,2],
 "group__API__HIP__Extensions.html#ga2da78e5b8b0ff08d2b78d8cdffe1b48f":[7,16,0],
-"group__API__HIP__Extensions.html#ga4e209f6f83eaa6707c37cd60f1dac3ff":[7,16,8],
-"group__API__HIP__Extensions.html#ga81c617c18f5cc3e4799fd6858e5c6d3f":[7,16,7],
-"group__API__HIP__Extensions.html#ga895d3031a83129e4c874eadedcfb1912":[7,16,1],
-"group__API__HIP__Extensions.html#ga9d7b2131ca9ed0d19535dcf5123145e2":[7,16,6],
-"group__API__HIP__Extensions.html#gaa67b3b12e9a0cce70c593b981ba14403":[7,16,9]
+"group__API__HIP__Extensions.html#ga4e209f6f83eaa6707c37cd60f1dac3ff":[7,16,8]
 };
