@@ -1,5 +1,9 @@
 var NAVTREEINDEX4 =
 {
+"group__API__HIP__Extensions.html#ga81c617c18f5cc3e4799fd6858e5c6d3f":[7,16,7],
+"group__API__HIP__Extensions.html#ga895d3031a83129e4c874eadedcfb1912":[7,16,1],
+"group__API__HIP__Extensions.html#ga9d7b2131ca9ed0d19535dcf5123145e2":[7,16,6],
+"group__API__HIP__Extensions.html#gaa67b3b12e9a0cce70c593b981ba14403":[7,16,9],
 "group__API__HIP__Extensions.html#gacb4a406b018e823790805c9d915dd052":[7,16,3],
 "group__API__HIP__Extensions.html#gad40f30899d319b57afe87e9f11e873e6":[7,16,12],
 "group__API__HIP__Extensions.html#gad433b07789156fd12e47cf35373d36c8":[7,16,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga04229edbc905be8eefce8fb58bfccf8f":[7,27,84],
 "group__API__MPI__Support.html#ga04576f1478a0416cd838c01269ba31a5":[7,27,8],
 "group__API__MPI__Support.html#ga0a464b972068bac652622d6a1ed0a996":[7,27,80],
-"group__API__MPI__Support.html#ga0b56f54628340aa2a47b080f96076f01":[7,27,25],
-"group__API__MPI__Support.html#ga0ec1ce958654468b20224c9ae772f98f":[7,27,22],
-"group__API__MPI__Support.html#ga1998499da59f8849a7ee5de16b0f5bab":[7,27,48],
-"group__API__MPI__Support.html#ga1d0194c08bd343a68c833f449fb62fa8":[7,27,33],
-"group__API__MPI__Support.html#ga1def2741166f560a0fb91f012538087f":[7,27,117]
+"group__API__MPI__Support.html#ga0b56f54628340aa2a47b080f96076f01":[7,27,25]
 };
