@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__mct__data":[7,22,4],
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__perfmodel__select__data":[7,22,6],
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__prio__data":[7,22,3],
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__specs":[7,22,7],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__tree":[7,22,1],
 "group__API__OpenCL__Extensions.html":[7,15],
 "group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[7,15,0,0],
@@ -245,9 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Worker.html#gga9adce159e1660dcd3ef111816b75b04da2a1da2eea8c82387f0877b7c7f7ff2a4":[7,37,28,2],
 "group__API__Parallel__Worker.html#gga9adce159e1660dcd3ef111816b75b04da6ec1cddc254911b1c4c6bc4103b615e5":[7,37,28,0],
 "group__API__Parallel__Worker.html#gga9adce159e1660dcd3ef111816b75b04daea3cad2ef001f27c6717b38e9738e11f":[7,37,28,1],
-"group__API__Perf__Monitoring.html":[7,38],
-"group__API__Perf__Monitoring.html#ga000af6e254ec5a3e95868f50d354f693":[7,38,4],
-"group__API__Perf__Monitoring.html#ga0a9c21a6b765059a5f5f72ab10dd99fa":[7,38,12],
-"group__API__Perf__Monitoring.html#ga0d09d776a8250c995d3e40d77bb10628":[7,38,33],
-"group__API__Perf__Monitoring.html#ga13f8e7f707f5bab7bc4f45291effd109":[7,38,15]
+"group__API__Perf__Monitoring.html":[7,38]
 };
