@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Perf__Monitoring.html#ga000af6e254ec5a3e95868f50d354f693":[7,38,4],
+"group__API__Perf__Monitoring.html#ga0a9c21a6b765059a5f5f72ab10dd99fa":[7,38,12],
+"group__API__Perf__Monitoring.html#ga0d09d776a8250c995d3e40d77bb10628":[7,38,33],
+"group__API__Perf__Monitoring.html#ga13f8e7f707f5bab7bc4f45291effd109":[7,38,15],
 "group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766":[7,38,24],
 "group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[7,38,1],
 "group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e":[7,38,11],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling__Tool.html#ga3316011101099a7bc5d68cd260dac1a3":[7,41,5],
 "group__API__Profiling__Tool.html#ga459877aae774d6576396522f2f7a935a":[7,41,4],
 "group__API__Profiling__Tool.html#ga51982063f84be225d47f8a0635184fe8":[7,41,6],
-"group__API__Profiling__Tool.html#ga9b4062bc6c18544ad5a1282672adb644":[7,41,7],
-"group__API__Profiling__Tool.html#structstarpu__prof__tool__api__info":[7,41,2],
-"group__API__Profiling__Tool.html#structstarpu__prof__tool__info":[7,41,0],
-"group__API__Profiling__Tool.html#unionstarpu__prof__tool__event__info":[7,41,1],
-"group__API__Random__Functions.html":[7,42]
+"group__API__Profiling__Tool.html#ga9b4062bc6c18544ad5a1282672adb644":[7,41,7]
 };
