@@ -1,5 +1,9 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Profiling__Tool.html#structstarpu__prof__tool__api__info":[7,41,2],
+"group__API__Profiling__Tool.html#structstarpu__prof__tool__info":[7,41,0],
+"group__API__Profiling__Tool.html#unionstarpu__prof__tool__event__info":[7,41,1],
+"group__API__Random__Functions.html":[7,42],
 "group__API__Running__Drivers.html":[7,32],
 "group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[7,32,0,1],
 "group__API__Running__Drivers.html#a50af396b52e8c54e4e3b23803105fc0e":[7,32,0,0],
@@ -245,9 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#ga6d8a3d42b5f2fee81785b3cf650fa6d2":[7,24,10],
 "group__API__Scheduling__Policy.html#ga706830b50d163715c28d2fb19abd13bd":[7,24,16],
 "group__API__Scheduling__Policy.html#ga7cfeacbeb8978b05754da35133eeba87":[7,24,26],
-"group__API__Scheduling__Policy.html#ga7f9281edd60ddfaeded3c920a77edbf7":[7,24,46],
-"group__API__Scheduling__Policy.html#ga8004f14208fd9b29f36440dc11ca765b":[7,24,25],
-"group__API__Scheduling__Policy.html#ga87e2aacf5892951d5333a3421e90f278":[7,24,33],
-"group__API__Scheduling__Policy.html#ga8e58ffd062043cf25b47c081b7f6ba88":[7,24,47],
-"group__API__Scheduling__Policy.html#ga8eb834f05df5337dcd8c96f6a74cd1f1":[7,24,41]
+"group__API__Scheduling__Policy.html#ga7f9281edd60ddfaeded3c920a77edbf7":[7,24,46]
 };
