@@ -1,5 +1,10 @@
 var NAVTREEINDEX11 =
 {
+"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[7,0,0,113],
+"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[6,0,0,113],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[7,0,0,114],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[6,0,0,114],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[6,0,0,115],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[7,0,0,115],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[6,0,0,116],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[7,0,0,116],
@@ -119,8 +124,8 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[7,0,0,173],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[7,0,0,174],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[6,0,0,174],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[7,0,0,175],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[6,0,0,175],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[7,0,0,175],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[6,0,0,176],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[7,0,0,176],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[6,0,0,177],
@@ -129,26 +134,26 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[7,0,0,178],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[7,0,0,179],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[6,0,0,179],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[6,0,0,180],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[7,0,0,180],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[6,0,0,180],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[7,0,0,181],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[6,0,0,181],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[6,0,0,182],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[7,0,0,182],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[6,0,0,182],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[7,0,0,183],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[6,0,0,183],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[6,0,0,184],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[7,0,0,184],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[7,0,0,185],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[6,0,0,185],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[7,0,0,186],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[6,0,0,186],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[6,0,0,187],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[7,0,0,186],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[7,0,0,187],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[6,0,0,187],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[6,0,0,188],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[7,0,0,188],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[6,0,0,189],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[7,0,0,189],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[6,0,0,189],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[6,0,0,190],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[7,0,0,190],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[6,0,0,191],
@@ -157,8 +162,8 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[7,0,0,192],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[6,0,0,193],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[7,0,0,193],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[7,0,0,194],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[6,0,0,194],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[7,0,0,194],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[7,0,0,195],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[6,0,0,195],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[7,0,0,196],
@@ -169,8 +174,8 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[6,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[7,0,0,199],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[6,0,0,199],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[6,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[7,0,0,200],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[6,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[6,0,0,201],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[7,0,0,201],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[7,0,0,202],
@@ -179,20 +184,20 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[6,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[6,0,0,204],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[7,0,0,204],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[7,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[6,0,0,205],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[7,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[7,0,0,206],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[6,0,0,206],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[7,0,0,207],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[6,0,0,207],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[7,0,0,207],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[7,0,0,208],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[6,0,0,208],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[6,0,0,209],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[7,0,0,209],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[6,0,0,210],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[6,0,0,209],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[7,0,0,210],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[6,0,0,211],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[6,0,0,210],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[7,0,0,211],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[6,0,0,211],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[6,0,0,212],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[7,0,0,212],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[6,0,0,213],
@@ -203,12 +208,12 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[7,0,0,215],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[6,0,0,216],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[7,0,0,216],
-"interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[7,0,0,217],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[6,0,0,217],
+"interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[7,0,0,217],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[6,0,0,218],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[7,0,0,218],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[6,0,0,219],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[7,0,0,219],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[6,0,0,219],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[6,0,0,220],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[7,0,0,220],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[6,0,0,221],
@@ -235,19 +240,14 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[6,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[7,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[6,0,0,232],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[7,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[6,0,0,233],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[6,0,0,234],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[7,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[7,0,0,234],
-"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[6,0,0,235],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[6,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[7,0,0,235],
+"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[6,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[7,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[6,0,0,236],
-"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[7,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[6,0,0,237],
-"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[7,0,0,238],
-"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[6,0,0,238],
-"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[7,0,0,239],
-"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[6,0,0,239],
-"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[6,0,0,240]
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[7,0,0,237]
 };
