@@ -1,5 +1,7 @@
 var NAVTREEINDEX2 =
 {
+"group__API__Data__Interfaces.html#ga0b6869745c464525b25a0757d112c318":[5,9,105],
+"group__API__Data__Interfaces.html#ga0cea5d347fdd4b5a44ecc9fe0295898c":[5,9,59],
 "group__API__Data__Interfaces.html#ga11d470bd48328eb4432e1c546ea22618":[5,9,175],
 "group__API__Data__Interfaces.html#ga12139db59366898a24b596bdaddb2d92":[5,9,164],
 "group__API__Data__Interfaces.html#ga18ffdda48c748445b090a7c54702f4c1":[5,9,44],
@@ -247,7 +249,5 @@ var NAVTREEINDEX2 =
 "group__API__Data__Management.html#ga78ffeb2e27e87bfc118e7fe2157ae4c2":[5,8,27],
 "group__API__Data__Management.html#ga7badde35fa2205201fad73fd851133fa":[5,8,30],
 "group__API__Data__Management.html#ga80778d87c0e2181096124f03bebe53cd":[5,8,6],
-"group__API__Data__Management.html#ga80b7284bb413ae7acac0fe83268c10f1":[5,8,50],
-"group__API__Data__Management.html#ga8771ea54051655e68ed7a95b4b831fc7":[5,8,32],
-"group__API__Data__Management.html#ga88a1a866445372adf0a07a349ecc7a5a":[5,8,10]
+"group__API__Data__Management.html#ga80b7284bb413ae7acac0fe83268c10f1":[5,8,50]
 };
