@@ -1,5 +1,7 @@
 var NAVTREEINDEX1 =
 {
+"group__API__Codelet__And__Tasks.html#a94baa4ce4eeab0a09edbeb4476eba98f":[7,6,2,61],
+"group__API__Codelet__And__Tasks.html#a964e4d78ecfbe8c10e392e83dd276299":[7,6,2,12],
 "group__API__Codelet__And__Tasks.html#a96fce0a6c6188a069d4bf2cc59e5400c":[7,6,2,45],
 "group__API__Codelet__And__Tasks.html#a9adac8be1a174cb4ad9d8e68c2ec7678":[7,6,2,38],
 "group__API__Codelet__And__Tasks.html#a9d78b1dc8fe2691f38fb16cdf726a376":[7,6,2,50],
@@ -247,7 +249,5 @@ var NAVTREEINDEX1 =
 "group__API__Data__Interfaces.html#ab5325b67d044c46f55dee56e32f352aa":[7,9,1,20],
 "group__API__Data__Interfaces.html#ab5bf46f3d89f5e55a5de88209ab579f5":[7,9,0,23],
 "group__API__Data__Interfaces.html#ab997f2654cd769dbd3413f5a90090a69":[7,9,1,27],
-"group__API__Data__Interfaces.html#aba2c4fceb446506eeaf77e78a7b8a632":[7,9,5,5],
-"group__API__Data__Interfaces.html#abc69fa030b4398af1663af656d91c2c5":[7,9,1,17],
-"group__API__Data__Interfaces.html#abccb7b1d3e85a19d010bec0e2202284f":[7,9,7,7]
+"group__API__Data__Interfaces.html#aba2c4fceb446506eeaf77e78a7b8a632":[7,9,5,5]
 };
