@@ -1,11 +1,15 @@
 var NAVTREEINDEX4 =
 {
+"group__API__FxT__Support.html#a069e624dee891479cec370e8078b26f5":[7,34,2,0],
+"group__API__FxT__Support.html#a156463ba1f63f97358f8ea039248178e":[7,34,1,3],
+"group__API__FxT__Support.html#a554098d2395577300ee6bd1da3c39f57":[7,34,2,1],
 "group__API__FxT__Support.html#a66ac04619aec557f95ddf5a5df848341":[7,34,2,4],
 "group__API__FxT__Support.html#a84459a45848577fda1ca80eb081c7af3":[7,34,1,2],
 "group__API__FxT__Support.html#ad55367cd96e01850fe91c645e64dbffb":[7,34,1,4],
 "group__API__FxT__Support.html#ad989ef1acebea5296285ba1543b9b8d3":[7,34,2,2],
 "group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c":[7,34,1,0],
 "group__API__FxT__Support.html#ae8b5695146698ba1d5aef8c9237b5272":[7,34,2,3],
+"group__API__FxT__Support.html#ga044878f9b946fd4c265ba6e725e2468c":[7,34,9],
 "group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1":[7,34,7],
 "group__API__FxT__Support.html#ga52a3e1a95689315f0b789a3325ec2a90":[7,34,5],
 "group__API__FxT__Support.html#ga5793bf5c8fc0bedf76d18a5fa38593df":[7,34,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__Interop__Support.html#gad2311ec339344d00bf5afdfa0ae4077b":[7,50,22],
 "group__API__Interop__Support.html#gad2af4e59ecca5dd01e2a7b914862c73c":[7,50,35],
 "group__API__Interop__Support.html#gadc9f8a043f8d1c2b44f0f942b0a8017c":[7,50,28],
-"group__API__Interop__Support.html#gaec539f82e7bc8fc9c2541b4a192486fb":[7,50,4],
-"group__API__Interop__Support.html#gaf6cca1c6f6a8d0a6cc73e8df687b4272":[7,50,16],
-"group__API__Interop__Support.html#gafbd3ffe388f6779226b4bb533e9e65d4":[7,50,59],
-"group__API__Interop__Support.html#gaff4a7845c85eeec3152526984a813cf6":[7,50,40],
-"group__API__Interop__Support.html#gaff61c047dc818553c56d9edeac379333":[7,50,29]
+"group__API__Interop__Support.html#gaec539f82e7bc8fc9c2541b4a192486fb":[7,50,4]
 };
