@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[7,22,26],
+"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[7,22,28],
+"group__API__Modularized__Scheduler.html#gabd7a0274979659050496fcc1c66b7a1c":[7,22,8],
+"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[7,22,55],
 "group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[7,22,66],
 "group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[7,22,23],
 "group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[7,22,74],
@@ -245,9 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Worker.html#ga6cd34b24aaea1b26df96b7aff9238759":[7,37,22],
 "group__API__Parallel__Worker.html#ga6dc4b6d66ef90b7927559c9e2728a84b":[7,37,21],
 "group__API__Parallel__Worker.html#ga6e2258c377e3aa838c2120904bf96f99":[7,37,34],
-"group__API__Parallel__Worker.html#ga718ac3b3060472256eceb68147a112b9":[7,37,26],
-"group__API__Parallel__Worker.html#ga777b13d6f49389771ce70e5c0fdfaf70":[7,37,33],
-"group__API__Parallel__Worker.html#ga7ebcf92c32971a58683063b536698996":[7,37,5],
-"group__API__Parallel__Worker.html#ga88471707cf8021453892ca7d83124bea":[7,37,13],
-"group__API__Parallel__Worker.html#ga97cd9955370e77c3b251dfc5e94c2080":[7,37,17]
+"group__API__Parallel__Worker.html#ga718ac3b3060472256eceb68147a112b9":[7,37,26]
 };
