@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Worker.html#ga777b13d6f49389771ce70e5c0fdfaf70":[7,37,33],
+"group__API__Parallel__Worker.html#ga7ebcf92c32971a58683063b536698996":[7,37,5],
+"group__API__Parallel__Worker.html#ga88471707cf8021453892ca7d83124bea":[7,37,13],
+"group__API__Parallel__Worker.html#ga97cd9955370e77c3b251dfc5e94c2080":[7,37,17],
 "group__API__Parallel__Worker.html#ga9adce159e1660dcd3ef111816b75b04d":[7,37,28],
 "group__API__Parallel__Worker.html#ga9b42af113646bf23c74e890fd766af31":[7,37,25],
 "group__API__Parallel__Worker.html#gab630219c3f24cfa1b3c096bdd19d5868":[7,37,27],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#ga6511f50290edcabbdf605a1b74746645":[7,40,21],
 "group__API__Profiling.html#ga6ab0a1e4a8a55e0c54e2151fd0a82a36":[7,40,5],
 "group__API__Profiling.html#ga76ad19fc8b99bcd42d505c76aafae6b6":[7,40,18],
-"group__API__Profiling.html#ga7c70803a54aa1e5b463ebb19110c4aa2":[7,40,11],
-"group__API__Profiling.html#ga858f465a2dcbcadb6169a7926e38a4d1":[7,40,12],
-"group__API__Profiling.html#ga87639260ff5c89f466e83fcc093e77fe":[7,40,20],
-"group__API__Profiling.html#ga8a423df93ec48a7391b2f439357a5544":[7,40,9],
-"group__API__Profiling.html#ga8cbf499dd0d62647b874fcb48c281e6a":[7,40,15]
+"group__API__Profiling.html#ga7c70803a54aa1e5b463ebb19110c4aa2":[7,40,11]
 };
