@@ -1,5 +1,9 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ga24154b37920144de18bca59090429d6d":[7,24,18],
+"group__API__Scheduling__Policy.html#ga2bb5cf545414379c1425a4b399fd75c2":[7,24,6],
+"group__API__Scheduling__Policy.html#ga2c45db0c01e86497082c907b9cb0f4cc":[7,24,14],
+"group__API__Scheduling__Policy.html#ga2dc83adec9e479e967a1d1c2ae40f916":[7,24,30],
 "group__API__Scheduling__Policy.html#ga315482308105aa57ecc59e88f71823aa":[7,24,42],
 "group__API__Scheduling__Policy.html#ga318f5a51b8f948940c754df6962be263":[7,24,35],
 "group__API__Scheduling__Policy.html#ga3893905aa0eb62a541f268c6f37c491e":[7,24,44],
@@ -181,14 +185,14 @@ var NAVTREEINDEX9 =
 "group__API__Toolbox.html":[7,35],
 "group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e":[7,35,10],
 "group__API__Toolbox.html#ga05ac0dda104331f57d85823a4f9318ce":[7,35,12],
-"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[7,35,21],
+"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[7,35,22],
 "group__API__Toolbox.html#ga10dac0e97a9c6bcc9ae042e067c508ae":[7,35,14],
-"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[7,35,19],
+"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[7,35,20],
 "group__API__Toolbox.html#ga214c60ee1b6cbc27ab08ba6f339ef8e5":[7,35,8],
 "group__API__Toolbox.html#ga230129f89ca986b143c6b059a9229fb7":[7,35,4],
 "group__API__Toolbox.html#ga23742c6fca8b5386e1f3e3f7bbf3a692":[7,35,1],
-"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[7,35,16],
-"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[7,35,17],
+"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[7,35,17],
+"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[7,35,18],
 "group__API__Toolbox.html#ga4456c2db2cc8df7c98d62ecc21b2bd1d":[7,35,2],
 "group__API__Toolbox.html#ga4fc771a29d7dc0e826da42777edbcf15":[7,35,0],
 "group__API__Toolbox.html#ga71e28fc2a0a5267bc7edc0909d9d5117":[7,35,9],
@@ -196,9 +200,10 @@ var NAVTREEINDEX9 =
 "group__API__Toolbox.html#ga7df091d95d10b854c16cd1cd65cf7508":[7,35,6],
 "group__API__Toolbox.html#ga9804db3e8ffb845492154f63e7d6ae95":[7,35,7],
 "group__API__Toolbox.html#ga9e7c20a6cdce868976a0046206b104e6":[7,35,3],
-"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[7,35,18],
-"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[7,35,20],
-"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[7,35,15],
+"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[7,35,19],
+"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[7,35,21],
+"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[7,35,16],
+"group__API__Toolbox.html#gad3ac8d7f5a35aa9c65dcca9915f9a750":[7,35,15],
 "group__API__Toolbox.html#gae07407908792f54312150228d70dbece":[7,35,5],
 "group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc":[7,35,11],
 "group__API__Transactions.html":[7,7],
@@ -244,10 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#ga38c0b1858730fec2211991147a964910":[7,18,69],
 "group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[7,18,45],
 "group__API__Workers.html#ga3a6a9eddecb3e97b3c37e151003ea7c2":[7,18,32],
-"group__API__Workers.html#ga3c4c7e122c29d884fe1674434b69cf52":[7,18,22],
-"group__API__Workers.html#ga3f985e55d355aa7b1c83471230b37a39":[7,18,39],
-"group__API__Workers.html#ga3fa9784ddcf3fc9f496e33fe4cad54ce":[7,18,38],
-"group__API__Workers.html#ga40eea17cbbabcb0eed906d0b50604ed2":[7,18,63],
-"group__API__Workers.html#ga45611e9799d1c32e826c5f2f6a642c65":[7,18,51],
-"group__API__Workers.html#ga479f8ed78324dca80ad746d0fee5d832":[7,18,7]
+"group__API__Workers.html#ga3c4c7e122c29d884fe1674434b69cf52":[7,18,22]
 };
