@@ -1,5 +1,8 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Explicit__Dependencies.html#ga863d71b775ec517493f81e731a64d134":[6,11,9],
+"group__API__Explicit__Dependencies.html#gab0761a67174503b61aa8d0e0ee1c9212":[6,11,16],
+"group__API__Explicit__Dependencies.html#gab5c86743355724ee2f9596de1ae221df":[6,11,10],
 "group__API__Explicit__Dependencies.html#gabaef95d742d03c96453905602e511050":[6,11,7],
 "group__API__Explicit__Dependencies.html#gabdb8d20fca507a93450fe775233dd20c":[6,11,15],
 "group__API__Explicit__Dependencies.html#gac350ef8b876d63fb8885377f789853d2":[6,11,0],
@@ -32,6 +35,7 @@ var NAVTREEINDEX4 =
 "group__API__FxT__Support.html#ad989ef1acebea5296285ba1543b9b8d3":[6,34,2,2],
 "group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c":[6,34,1,0],
 "group__API__FxT__Support.html#ae8b5695146698ba1d5aef8c9237b5272":[6,34,2,3],
+"group__API__FxT__Support.html#ga044878f9b946fd4c265ba6e725e2468c":[6,34,9],
 "group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1":[6,34,7],
 "group__API__FxT__Support.html#ga52a3e1a95689315f0b789a3325ec2a90":[6,34,5],
 "group__API__FxT__Support.html#ga5793bf5c8fc0bedf76d18a5fa38593df":[6,34,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__Interop__Support.html#ga6857b66748130956d7f6d256e45511ed":[6,50,7],
 "group__API__Interop__Support.html#ga6a488948dfca7de9ea6181e9546534e5":[6,50,39],
 "group__API__Interop__Support.html#ga6c5ab5ff822db23f7877c4e9a6632223":[6,50,24],
-"group__API__Interop__Support.html#ga6d7cb1a372417ba039fd80738b09859c":[6,50,46],
-"group__API__Interop__Support.html#ga6e3313ab94d5bef08fbdf87672a9c699":[6,50,63],
-"group__API__Interop__Support.html#ga6f6adfe90ef0bb6f1a17750fb5424304":[6,50,36],
-"group__API__Interop__Support.html#ga775088fa987f23dcf1ff50484d04964a":[6,50,53],
-"group__API__Interop__Support.html#ga7821f8af5e91529e05e91ae0673c34b0":[6,50,11]
+"group__API__Interop__Support.html#ga6d7cb1a372417ba039fd80738b09859c":[6,50,46]
 };
